@@ -13,7 +13,7 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: cutCopyPaste.c,v 1.9 1996/04/19 09:56:38 torsten Exp $ */
+/* $Id: cutCopyPaste.c,v 1.11 1997/05/07 05:53:50 torsten Exp $ */
 
 #include <X11/StringDefs.h>
 #include <X11/Intrinsic.h>
@@ -70,10 +70,31 @@ selectionConvert(Widget w, Atom * selection, Atom * target,
     Pixmap *pix, np;
     GC gc;
     int wth, hth, dth;
+    static Atom A_TARGETS = 0;
 
     if (src == None)
 	return False;
 
+    if (A_TARGETS == 0)
+      A_TARGETS = XInternAtom (XtDisplay(w), "TARGETS", False);
+
+    if (*target == A_TARGETS)
+      {
+	Atom *targets;
+	int num_targets = 3;
+
+	targets = (Atom *) XtMalloc (sizeof (Atom) * num_targets);
+	targets[0] = XA_PIXMAP;
+	targets[1] = XA_BITMAP;
+	targets[2] = A_TARGETS;
+	*type = XA_ATOM;
+	*value = (XtPointer) targets;
+	*len = num_targets;
+	*format = 32;
+	return True;
+      }
+    
+
     if (*target != XA_PIXMAP && *target != XA_BITMAP)
 	return False;
 
@@ -444,7 +465,7 @@ ImgProcessSetup(Widget paint)
     if (!PwRegionGet(paint, &ImgProcessPix, None)) {
 #ifdef FILTERNEEDSSELECTION
 	StateSetBusy(False);
-	return;			/* No region selected */
+	return NULL;			/* No region selected */
 #else
 	PaintWidget pw = (PaintWidget) paint;
 
@@ -496,7 +517,8 @@ stdImgProcess(Widget paint, Image * (*func) (Image *))
     lastFilter = func;
     EnableLast(paint);
 
-    in = ImgProcessSetup(paint);
+    if ((in = ImgProcessSetup(paint)) == NULL)
+	return;
     out = ImgProcessFinish(paint, in, func);
 }
 
